@@ -13,15 +13,18 @@ config = AutoConfig(search_path=dir_path)
 logger = logging.getLogger()
 logger.setLevel(logging.INFO)
 
-con = logging.StreamHandler()
-con.setLevel(logging.INFO)
-
-formatter = logging.Formatter('%(message)s')
-con.setFormatter(formatter)
-logger.addHandler(con)
+# con = logging.StreamHandler()
+# con.setLevel(logging.INFO)
+# formatter = logging.Formatter('%(message)s')
+# con.setFormatter(formatter)
+# logger.addHandler(con)
 
 def set_tags(key,value):
         extra_tags[key]=value
+def get_tags(key):
+        if key in extra_tags:
+                return  extra_tags[key]
+        return None
 def merge_two_dicts(x, y):
         z = x.copy()   # start with x's keys and values
         z.update(y)    # modifies z with y's keys and values & returns None
